tests package — django_analyses 0.0.3 documentation

# tests package

## Subpackages

- tests.factories package
  - Subpackages
    - tests.factories.input package
    - tests.factories.pipeline package
  - Submodules
  - tests.factories.analysis module
  - tests.factories.analysis_version module
  - tests.factories.category module
  - tests.factories.run module
  - tests.factories.user module
  - Module contents
- tests.models package
  - Subpackages
    - tests.models.input package
    - tests.models.managers package
    - tests.models.output package
    - tests.models.pipeline package
  - Submodules
  - tests.models.test_analysis module
  - tests.models.test_analysis_version module
  - tests.models.test_category module
  - tests.models.test_run module
  - Module contents

## Submodules

## tests.fixtures module

## tests.interfaces module

class `tests.interfaces.` `Addition`(x: float, y: float)

  Bases: `object`

  `calculate`() → dict

class `tests.interfaces.` `Division`(dividend: float, divisor: float = 2.0)

  Bases: `object`

  `run`() → dict

class `tests.interfaces.` `DivisionResults`(results: dict)

  Bases: `object`

class `tests.interfaces.` `NormCalculation`(x, order: str = None)

  Bases: `object`

  `determine_order`()
  `normalize`()

class `tests.interfaces.` `Power`(base: float, exponent: float)

  Bases: `object`

  `run`() → dict

## tests.test_pipeline_runner module

class `tests.test_pipeline_runner.` `PipelineRunnerTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `PipelineRunner` model.

  `setUp`()

    For more information see unittest’s `setUp()` method.

  classmethod `setUpTestData`()

    Load initial data for the TestCase.

  `test_get_destination_kwarg`()
  `test_get_incoming_pipes`()
  `test_get_node_inputs`()
  `test_has_required_runs_with_no_runs_returns_false`()
  `test_has_required_runs_with_partial_runs_returns_false`()
  `test_has_required_runs_with_runs_returns_true`()
  `test_run`()
  `test_run_entry_nodes`()
  `test_run_node`()

## tests.test_settings module

## Module contents